@@ -204,7 +204,7 @@ class Font(object):
     ]
     _WIDTHS_BY_VALUE = {width["value"]: width for width in _WIDTHS}
 
-    def __init__(self, filepath):
+    def __init__(self, filepath, lazy=False):
         """
         Constructs a new Font instance loading a font file from the given filepath.
 
@@ -216,20 +216,23 @@ class Font(object):
         super(Font, self).__init__()
 
         self._filepath = None
+        self._lazy = None
         self._ttfont = None
 
         if isinstance(filepath, str):
-            self._init_with_filepath(filepath)
+            self._init_with_filepath(filepath, lazy=lazy)
         else:
             filepath_type = type(filepath).__name__
             raise ValueError(
                 f"Invalid filepath type: expected str, found '{filepath_type}'."
             )
 
-    def _init_with_filepath(self, filepath):
+    def _init_with_filepath(self, filepath, lazy=False):
         try:
-            self._ttfont = TTFont(filepath)
             self._filepath = filepath
+            self._lazy = lazy
+            self._ttfont = TTFont(self._filepath, lazy=self._lazy)
+
         except TTLibError:
             raise ValueError(f"Invalid font at filepath: '{filepath}'.")
 
@@ -243,7 +246,7 @@ class Font(object):
         """
         Creates a new Font instance reading the same binary file.
         """
-        return Font(self._filepath)
+        return Font(self._filepath, lazy=self._lazy)
 
     def close(self):
         """
@@ -345,7 +348,7 @@ class Font(object):
         img = self.get_image(text=text[0], size=72)
         img_size = img.size
         img = img.resize((img_size[0] // 2, img_size[1] // 2))
-        img = img.resize((img_size[0], img_size[1]), Image.NEAREST)
+        img = img.resize((img_size[0], img_size[1]), Image.Resampling.NEAREST)
         img = img.quantize(colors=2)
         # img.show()
 
@@ -900,8 +903,10 @@ class Font(object):
         if subfamily_name not in subfamily_names:
             subfamily_name = subfamily_name_default
 
+        subfamily_name = subfamily_name.title()
+
         # full name
-        full_name = concat_names(typographic_family_name, typographic_subfamily_name)
+        full_name = concat_names(family_name, subfamily_name)
 
         # postscript name
         postscript_name = concat_names(
